xila_file_system_directory_get_statistics

Function xila_file_system_directory_get_statistics 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_directory_get_statistics( directory: *mut XilaFileSystemDirectory, statistics: *mut XilaFileSystemStatistics, ) -> XilaFileSystemResult
This function is used to get the statistics of a directory.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a directory.