xila_file_system_directory_rewind

Function xila_file_system_directory_rewind 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_directory_rewind( directory: *mut XilaFileSystemDirectory, ) -> XilaFileSystemResult
This function is used to rewind a directory.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a directory.