xila_file_system_file_advise

Function xila_file_system_file_advise 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_file_advise( _file: *mut XilaFileSystemFile, _offset: XilaFileSystemSize, _length: XilaFileSystemSize, _advice: u8, ) -> XilaFileSystemResult
This function is used to advice the file system about the access pattern of a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.