xila_file_system_file_flush

Function xila_file_system_file_flush 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_file_flush( file: *mut XilaFileSystemFile, _t: bool, ) -> XilaFileSystemResult
This function is used to flush a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized `XilaFile