xila_file_system_file_get_state

Function xila_file_system_file_get_state 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_file_get_state( file: *mut XilaFileSystemFile, state: *mut XilaFileSystemState, ) -> XilaFileSystemResult
This function is used to get the flags of a file.

Safety

This function is unsafe because it dereferences raw pointers.