xila_file_system_file_get_statistics

Function xila_file_system_file_get_statistics 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_file_get_statistics( file: *mut XilaFileSystemFile, statistics: *mut XilaFileSystemStatistics, ) -> XilaFileSystemResult
This function is used to get the statistics of a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.

Errors

This function may return an error if the file system fails to get the statistics of the file.