xila_file_system_get_state_flags

Function xila_file_system_get_state_flags 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xila_file_system_get_state_flags( _file: XilaFileIdentifier, _status: *mut XilaFileSystemState, ) -> XilaFileSystemResult
This function is used to get the flags of a file.

Safety

This function is unsafe because it dereferences raw pointers.