#[unsafe(no_mangle)]pub unsafe extern "C" fn xila_file_system_file_set_flags(
_file: *mut XilaFileSystemFile,
_state: XilaFileSystemState,
) -> XilaFileSystemResultExpand description
This function is used to set the flags of a file.
Safety
The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.